from __future__ import annotations

import itertools
from typing import List

_case_list = ["用户名", "密码"]
_value_list = ["正确", "不正确", "特殊符号", "超过最大长度"]


def add_one(number: int) -> int:
    return number + 1


def gen_case(item: List[str] = _case_list, value: List[str] = _value_list) -> None:
    """输出笛卡尔用例集合"""
    for i in itertools.product(item, value):
        print("输入".join(i))


def _test_print() -> None:
    print("欢迎搜索关注公众号: 「测试开发技术」!")


if __name__ == "__main__":
    _test_print()



from __future__ import annotations


# 导入module 而不是导入函数或者类 可以避免循环import的问题
from dknovautils import commons
from dknovautils.commons import *


class DkIpyUtils(object):
    @staticmethod
    def hello(a: Any) -> Any:
        commons.iprint_info("hello")
        return a  # 为了测试该文件是否正常

    @staticmethod
    def mfc(cmd: str, verbose: bool = True) -> None:
        DkIpyUtils.mfr(cmd, verbose)

    _cmd_id = 1000

    @staticmethod
    def mfr(cmd: str, getoutput: Callable, verbose: bool = True) -> Any:
        """
        为了去掉对ipython的依赖 需要调用方传入函数 getoutput

            from IPython.core.getipython import get_ipython
            getoutput = get_ipython().getoutput
            cmd='ls'
            r= DkIpyUtils.mfr(cmd,getoutput)

        """
        assert cmd and getoutput, "err24618"
        # 这样局部import 只有执行这个函数的时候 才依赖ipython
        # from IPython.core.getipython import get_ipython  # type ignore[import-untyped]

        assert isinstance(cmd, str) and len(cmd) > 0, "err3581"
        DkIpyUtils._cmd_id += 1
        if verbose:
            commons.iprint_info(f"run cmd begin {DkIpyUtils._cmd_id}: {cmd}")

        # r = get_ipython().getoutput(cmd)  # type:ignore
        r = getoutput(cmd)  # type:ignore

        if verbose:
            commons.iprint_info(f"run cmd end {DkIpyUtils._cmd_id}")

        return r


def dk_mfc(cmd: str, verbose: bool = True) -> None:
    DkIpyUtils.mfc(cmd, verbose)


def dk_mfr(cmd: str, verbose: bool = True) -> Any:
    return DkIpyUtils.mfr(cmd, verbose)


"""

!{cmd}

r=get_ipython().getoutput('{cmd}')



不能用 %cd 格式化会出错 用 os.chdir()

不用 echo 用 iprint






"""



from __future__ import annotations
from dknovautils import *
from dknovautils.dk_cmdutils import CmdUtils


"""

env | python3 -m dknovautils prefix



"""


def main(args) -> None:

    subcmd = args.subcmd
    if subcmd == "prefix":
        CmdUtils.add_dt_prefix()
    elif subcmd == "dtnc":
        sc_dtnc()
    elif False:
        pass
    else:
        iprint(f"hello from {DkAppVer}")


def sc_dtnc():
    # dtnc
    slen = len("2025-01-27T12-07-39")
    sr = AT.sdf_logger_format_datetime(precise="a", noColon=True)[:slen]
    print(sr, flush=True)


if __name__ == "__main__":

    import argparse

    parser = argparse.ArgumentParser()

    parser.add_argument("subcmd", help="subcmd= hello add_prefix")

    if False:

        parser.add_argument("-d", "--dir", nargs=None, type=str, help="dir")
        parser.add_argument("-p", "--passwd", nargs=None, type=str, help="passwd")
        parser.add_argument("-s", "--subj", nargs=None, type=str, help="subj")
        parser.add_argument("--server", nargs=None, type=str, help="server")
        parser.add_argument("--sslport", nargs=None, type=int, help="port")

        # 这两个变量只跟 htpasswd文件有关 如果更新密码只需要更新这个文件即可
        parser.add_argument(
            "--auth-name", nargs=None, type=str, default="dknova", help="auth-name"
        )
        parser.add_argument(
            "--auth-pwd", nargs=None, type=str, default="123456", help="auth-pwd"
        )

        # parser.add_argument('-p', '--port', nargs=1, type=int, default=8005, help='port')

    args = parser.parse_args()

    if False:
        if not args.dir:
            args.dir = "/home/dknova/test_https"

        AT.assert_(AT.is_linux, "err93757 程序需要在linux环境中运行")

    main(args)



from __future__ import annotations

import logging

from typing import List, Dict, Tuple, Union, Any

import random
import time

import math
import random
from collections import namedtuple, deque
import re
import sys


import os
import subprocess
from queue import Queue
from queue import Empty
from pathlib import Path
import itertools
import itertools as ite

import threading

import hashlib


import time
from datetime import datetime
from datetime import date


from enum import Enum, unique

import base64
import argparse
import random
import time
import os

from typing import Callable, List, Dict, Tuple, Union, Any, Deque
from typing import Iterable, TYPE_CHECKING

import os, sys, math
import logging
import time
from datetime import datetime
from datetime import date

from collections import deque

import threading

import os
from os.path import join, getsize
import shutil
from pathlib import Path
from typing import List, Dict, Iterator, Set, Tuple

from functools import *

import traceback


# ---------------------------------------

# 这是非系统内置的 第三方库 集中写在此处
try:
    import numpy as np
    import urllib3
    import pyperclip

    from dataclasses import dataclass
    import dataclasses

finally:
    pass


# ----------------------------------------


class LLevel(Enum):
    Trace = 5
    Debug = 10
    Info = 20
    Warn = 30
    Error = 40


# -----------Add Trace Level----------------------

"""

https://stackoverflow.com/questions/2183233/how-to-add-a-custom-loglevel-to-pythons-logging-facility


"""

from logging import getLoggerClass, addLevelName, setLoggerClass, NOTSET

Trace_ = 5


class MyLogger(getLoggerClass()):
    def __init__(self, name, level=NOTSET):
        super().__init__(name, level)

        addLevelName(Trace_, "Trace")

    def verbose(self, msg, *args, **kwargs):
        if self.isEnabledFor(Trace_):
            self._log(Trace_, msg, args, **kwargs)


setLoggerClass(MyLogger)



from __future__ import annotations


from dknovautils import commons, iprint_debug, iprint_warn, AT  # type:ignore
from dknovautils.commons import *  # type: ignore

from enum import Enum, auto, unique

import sys


class CmdUtils:

    @classmethod
    def add_dt_prefix(cls, prefix: str = "dateIms") -> None:
        """
    给标准输入的每一行前面附加 当前的时间戳的前缀。
    
使用方法

env | python3 -m dknovautils prefix

	py函数 给 stdin 分行 加上前缀 40分钟 更新py库
	
		add_line_prefix
	
		-p dateI
		-p dateIs
		-p dateIns
		-p date
		
		输出分行符号 根据os来决定
        
        
        """
        cls.add_datetime_prefix_per_stdin_line(prefix=prefix)

    @classmethod
    def add_datetime_prefix_per_stdin_line(cls, prefix: str) -> None:
        """
        # _prefixs = ["date", "dateI", "dateIs", "dateIns"]

        std_input = sys.stdin.readline().rstrip('\n')  # Remove trailing newline

        """

        class Pref(Enum):
            date = 10
            dateI = 20
            dateIs = 40
            dateIms = 50
            dateIns = 60

        _prefixs = [str(name) for name, _ in Pref.__members__.items()]

        assert (
            prefix in _prefixs
        ), f"err71055 'prefix' should be one of {_prefixs}. prefix:{prefix} "

        preE = Pref[prefix]

        def fprefix() -> str:  # type: ignore
            noColon = False
            if preE == Pref.date:
                # todo
                return AT.sdf_logger_format_datetime(precise="d", noColon=noColon)
            elif preE == Pref.dateI:
                # date -I
                return AT.sdf_logger_format_datetime(precise="d", noColon=noColon)
            elif preE == Pref.dateIs:
                # date -Is
                return AT.sdf_logger_format_datetime(precise="s", noColon=noColon)
            elif preE == Pref.dateIms:
                # 
                return AT.sdf_logger_format_datetime(precise="ms", noColon=noColon)            
            elif preE == Pref.dateIns:
                # todo
                return AT.sdf_logger_format_datetime(precise="a", noColon=noColon)
            else:
                AT.never("err18903")
                
                    
        import sys

        @dataclass
        class LN:
            last: str | None
            curr: str | None

        SN = 50

        def _f_parts() -> Iterator[LN]:
            last: str | None = None
            while True:
                data = sys.stdin.readline(SN)
                if False:
                    AT.never()
                elif len(data) == 0:
                    # EOF
                    yield LN(last=last, curr=None)
                    break
                else:
                    yield LN(last=last, curr=data)
                    last = data

        BRK = "\n"
        NBK = "\n"
        END = ""
        flush = True

        for ln in _f_parts():
            if False:
                print(f"\nyield: [{ln.last}] [{ln.curr}] \n")

            if ln.curr is None:
                print(NBK, end=END, flush=flush)
                break
            elif ln.last is None:
                prefix = fprefix() #"2012-12-12"
                ostr = prefix + " " + ln.curr.rstrip(BRK)
                print(ostr, end=END, flush=flush)
            elif ln.last.endswith(BRK):
                prefix = fprefix() #"2012-12-12"
                ostr = NBK + prefix + " " + ln.curr.rstrip(BRK)
                print(ostr, end=END, flush=flush)
            elif not ln.last.endswith(BRK):
                ostr = ln.curr.rstrip(BRK)
                print(ostr, end=END, flush=flush)
            else:
                AT.never()
                
                
                

        # BRN = "\n"
        # for line in sys.stdin:
        #     line = line.rstrip(BRN)
        #     line = fprefix() + " " + line
        #     # should flush the buffer
        #     print(line,flush=True)
            
            


# def f_add_prefix():

            


if __name__ == "__main__":

    print("input some str")

    CmdUtils.add_dt_prefix(prefix="dateIns")

    print("end all ok")

    pass
